#
# spec file for package hardinfo2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hardinfo2
Version:        2.2.4
Release:        1.1
Summary:        A System Information and Benchmark for Linux
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND LGPL-2.0-or-later AND GPL-3.0-or-later AND LGPL-2.1-only
Group:          System/Benchmark
URL:            https://www.hardinfo2.org/
Source0:        https://github.com/hardinfo2/hardinfo2/archive/release-%{version}/%{name}-release-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  openSUSE-release
BuildRequires:  pciutils
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cairo-png)
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(zlib)
Recommends:     Mesa-demo-x
Recommends:     dmidecode
Recommends:     iperf
Recommends:     lsscsi
Recommends:     sensors
Recommends:     sysbench
Recommends:     udisks2
Recommends:     vulkan-tools
Recommends:     xdg-utils
Recommends:     xrandr

%description
Hardinfo2 is based on hardinfo.

Hardinfo2 offers System Information and Benchmark for Linux Systems. It is able
to obtain information from both hardware and basic software. It can benchmark
your system and compare to other machines online.

Features include:
 - Report generation (in either HTML or plain text)
 - Online Benchmarking - compare your machine against other machines

%prep
%autosetup -p1 -n %{name}-release-%{version}

%build
%cmake \
    -DCMAKE_BUILD_TYPE=Release

%cmake_build

%install
%cmake_install

desktop-file-install --vendor="" \
  --set-generic-name='Hardware Information' \
  --add-category="Settings;HardwareSettings;" \
  --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/%{name}.desktop

%fdupes %{buildroot}%{_datadir}

%find_lang %{name}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files -f %{name}.lang
%doc README.md
%license LICENSE LICENSE.1 LICENSE.2
%{_bindir}/%{name}
%{_bindir}/hwinfo2_fetch_sysdata
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/hardinfo2.svg
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/metainfo/org.hardinfo2.hardinfo2.metainfo.xml
%{_unitdir}/hardinfo2.service

%changelog
* Sat Nov  9 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 2.2.4:
  * Fixed missing "join hardinfo2 group" text on some distros
  * Fixed start crash - fread possible overread on some distros
  * Fixed Loongarch build errors
  * Fixed CPACK debian depends
  * Distro support added: Gentoo, LiGurOS, ZorinOS, Artix Linux
  * Minor fixes: optimize source file space usage, arm cpus
* Thu Oct 24 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 2.2.1:
  * Security Fix for Multi User Systems #93 IMPORTANT
    (boo#1231839)
  * PACKAGING: Please remove 2.1.14 & 2.1.17 containing security
    bug IMPORTANT
  * PACKAGING: Changed services (systemV/D+runit) to use common
    script hwinfo2_fetch_sysdata IMPORTANT
  * PACKAGING: CPack changed to depends instead of recommends.
  * Users must be added to hardinfo2 group to keep data safe.
  * Improved UI - New SVG versions of ALL icons!
  * Manual High DPI scaling support - GDK_DPI_SCALE=1.5 hardinfo2
  * Improved HTML report - new theme, fixed html gen, images incl.
    in print version.
  * Improved SVG for distro logos, hardinfo2 logo - fixed for
    old distro.
  * Support for Alpine Linux, postmarketOS, OpenMandriva,
    Parrot sec, MX Linux
  * Minor fixes: PO comments, ru+da translations, html dialog
    modal fix, flicker fix,
  * Minor fixes: musl support, arm cpus, battery health info,
    kernel boots, arm/risc meta cpu info added.
* Thu Oct 17 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 2.1.17:
  * PACKAGING: Add recommends: xrandr (rpm only, is in deb) &
    vulkan-tools IMPORTANT
  * Fix Crash Bugs: Display refresh, DDR5 on 6.11 kernel IMPORTANT
  * New Storage Benchmarking
  * New Vulkan info on display page
  * New SPD DDR5 DIMM decoding support (Kernel 6.11+)
  * New Based on Distro Detection along with Distro logos and links
  * Several minor fixes, updates and UI/UX improvements:
  * machine_type was translated when synchronize to server
  * code gcc warnings, restructured spd decode
  * SPD eeprom (deprecated but needed on history machines),
    Added filtering support
  * Added packaging/building support for more distros
  * JSON: Devicetree compatible to enable updating internal tables
    for missing CPUs (Arm,RiscV,Loong64)
  * Fixed gnome detect new version for theme control,
    Budgie, Mate, etc.
  * Hardinfo2 logo updated to SVG
  * Tool versions detection updated
  * Minor Risc-V board additions.
  * GPU Naming improvements
  * Auto scroll to This machine benchmarks
- Add Recommends vulkan-tools and xrandr
* Mon Sep 16 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 2.1.14:
  * PACKAGING: Added service (Allows memory DMI+SPD & resources
    iomem+ioports)
  * PACKAGING: Added build dependencies (DEB:libqt5opengl5-dev
    qtbase5-dev)/(FEDORA:qt5-qtbase-devel)
  * PACKAGING: BinReloc disabled for all distros - using CMAKE
  * New OpenGL benchmark using QT5
  * Fixed GPU benchmarks to show GPU instead of CPU in table
  * CleanUserData on first run and program version changes
  * Improve light themes, Updated anime theme
  * Minor fixes, translations, isa ARM+RISCV updates, cpu
    topology fixes, cpu flags fix, minor CLI
  * Minor fixes, improve GPU name, improve distro name
  * Added RISC-V identification table
  * Memory SPD Vendor table update, minor updates
    to PCI+USB tables
  * Memory SPD & DMI and resources from user space via service
  * Danish translation
  * Added metainfo for appcenters
  * Readded E2000 CPU Support after license change acceptance
  * Fixes for PCLinuxOS+PureOS10+Devuan CPack building
  * Fixes for NixOS+Nix, WSL2, Rasbian, RaspberryPi and
    old distros
- Rebase BuildRequires
* Mon Jun  3 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 2.1.11:
  * Fixed theme change not supporting native system settings
    theme setup.
  * Fixed background light/dark mode could be wrong depending
    on DE version
- Changes in version 2.1.8:
  * Fixed critical error - app was unreadable due to faulty
    dark mode detection
  * Added gsettings and dynamic darkmode for newer distros
- Changes in version 2.1.5:
  * PACKAGING: Recommends updated: add fwupd
  * Build updated to CMake 3.0.2 and more verbose/check during
    CPack builds
  * Build hardcoded prefix=/usr - we only build packages or
    install directly to package destination.
  * Fixed Translations not working in all distros/Packages
  * Fixed Memory Devices asked for root
  * Added loong64 as loongarch64 architecture
  * Added mips64el as mips architecture
  * Added Hungarian language
  * Minor: Fixed GCC warnings for modules/architectures, implicit
    function declarations, runtime warnings
* Mon May 20 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 2.1.2:
  * Themes support added along with 6 themes for dark and
  light mode.
  * Memory_usage updated
  * UI/UX improved (Notes color scheme fixed for dark/light mode,
  scrollbars, sorting, string wrap, man page updated)
  * CLI - Skip benchmark reporting when -s (skip benchmark)
  * User Note for group benchmarks - more to come on this topic
  in user guide
  * Added network interface speed
  * Minor fixes - deprecated functions, gcc warning, runtime
  warning, implicit ctype functions, uninitialized variable
  * Fix Reload details after synchronize - M11
  * Fix frozen app window, focus loss every second time
  benchmarking - M13
  * Fix Benchmark shows too many records when not completed
  * Fix lowering flash in GUI benchmark for epileptics.
* Tue May 14 2024 Carsten Ziepke <kieltux@gmail.com>
- Initial version, based on the spec files from daviddavid (Mageia)
  and topazus (Fedora)
